==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/ractiondef.h <==
/***************************************************************************
                          ractiondef.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

// Action defines:
//

#ifndef RACTIONDEF_H
#define RACTIONDEF_H


// Zoom:
//
#define ACT_ZOOM_FIRST        1
#define   ACT_ZOOM_WINDOW       1
#define   ACT_ZOOM_PAN          2
#define ACT_ZOOM_LAST         2


// Draw:
//
#define ACT_DRAW_FIRST       21

#define   ACT_POINTS_FIRST     21
#define     ACT_POINTS_SINGLE    21
#define   ACT_POINTS_LAST      21

#define   ACT_LINES_FIRST      41
#define     ACT_LINES_NORMAL     41
#define     ACT_LINES_HOR        42
#define     ACT_LINES_VER        43
#define     ACT_LINES_ANGLE      44
#define     ACT_LINES_RECT       45
#define     ACT_LINES_PARA       46
#define     ACT_LINES_BISECTOR   47
#define     ACT_LINES_TAN1       48
#define     ACT_LINES_TAN2       49
#define     ACT_LINES_ORTHO      50
#define     ACT_LINES_ORTHO2     51
#define   ACT_LINES_LAST       51

#define   ACT_ARCS_FIRST       55
#define     ACT_ARCS_CRAA        55
#define     ACT_ARCS_PPP         56
#define     ACT_ARCS_PARA        57
#define   ACT_ARCS_LAST        57

#define   ACT_CIRCLES_FIRST    61
#define     ACT_CIRCLES_CR       61
#define   ACT_CIRCLES_LAST     61

#define   ACT_TEXTS_FIRST      71
#define     ACT_TEXTS_NORMAL     71
#define   ACT_TEXTS_LAST       71

#define   ACT_DIMS_FIRST       81
#define     ACT_DIMS_PARA        81
#define     ACT_DIMS_HOR         82
#define     ACT_DIMS_VER         83
#define     ACT_DIMS_ANGLE       84
#define     ACT_DIMS_DIAM        85
#define     ACT_DIMS_RAD         86
#define     ACT_DIMS_ARROW       87
#define   ACT_DIMS_LAST        87

#define   ACT_HATCH_FIRST      91
#define     ACT_HATCH            91
#define   ACT_HATCH_LAST       91

#define ACT_DRAW_LAST        91


// Tag:
//
#define ACT_TAG_FIRST        101
#define   ACT_TAG_ELEMENT     101
#define   ACT_TAG_CONTOUR     102
#define   ACT_UNTAG_RANGE     103
#define   ACT_TAG_RANGE       104
#define   ACT_UNTAG_INTERS    105
#define   ACT_TAG_INTERS      106
#define   ACT_TAG_LAYER       107
#define ACT_TAG_LAST         107


// Edit:
//
#define ACT_EDIT_FIRST       201
#define   ACT_EDIT_MOVE       201
#define   ACT_EDIT_ROTATE     202
#define   ACT_EDIT_SCALE      203
#define   ACT_EDIT_MIRROR     204
#define   ACT_EDIT_MOVEROTATE 205
#define   ACT_EDIT_ROTATEROTATE 206
#define   ACT_EDIT_TRIM       207
#define   ACT_EDIT_TRIM2      208
#define   ACT_EDIT_CUT        209
#define   ACT_EDIT_STRETCH    210
#define   ACT_EDIT_ROUND      211
#define   ACT_EDIT_BEVEL      212
#define   ACT_EDIT_TEXTELEMENTS 213
#define   ACT_EDIT_TEXT       214
#define   ACT_EDIT_DELETE     215
#define   ACT_EDIT_LAYER      216
#define   ACT_EDIT_ZERO       217
#define   ACT_EDIT_ATTRIB     218

#define   ACT_EDIT_CLIPCOPY   220
#define   ACT_EDIT_CLIPCUT    221
#define   ACT_EDIT_CLIPPASTE  222
#define ACT_EDIT_LAST        222


// CAM:
//
#define ACT_CAM_FIRST       501
#define   ACT_CAM_AUTO        501
#define   ACT_CAM_MANUAL      502
#define ACT_CAM_LAST        502

#endif

// EOF

==> qcad_1.4.7.orig.tar.gz: qcad-1.4.7.orig/ractiondef.h <==
/***************************************************************************
                          ractiondef.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

// Action defines:
//

#ifndef RACTIONDEF_H
#define RACTIONDEF_H


// Zoom:
//
#define ACT_ZOOM_FIRST        10
#define   ACT_ZOOM_WINDOW       10
#define   ACT_ZOOM_PAN          11
#define ACT_ZOOM_LAST         11


// Draw:
//
#define ACT_DRAW_FIRST       21

#define   ACT_POINTS_FIRST     21
#define     ACT_POINTS_SINGLE    21
#define   ACT_POINTS_LAST      21

#define   ACT_LINES_FIRST      41
#define     ACT_LINES_NORMAL     41
#define     ACT_LINES_HOR        42
#define     ACT_LINES_VER        43
#define     ACT_LINES_ANGLE      44
#define     ACT_LINES_RECT       45
#define     ACT_LINES_PARA       46
#define     ACT_LINES_BISECTOR   47
#define     ACT_LINES_TAN1       48
#define     ACT_LINES_TAN2       49
#define     ACT_LINES_ORTHO      50
#define     ACT_LINES_ORTHO2     51
#define   ACT_LINES_LAST       51

#define   ACT_ARCS_FIRST       55
#define     ACT_ARCS_CRAA        55
#define     ACT_ARCS_PPP         56
#define     ACT_ARCS_PARA        57
#define   ACT_ARCS_LAST        57

#define   ACT_CIRCLES_FIRST    61
#define     ACT_CIRCLES_CR       61
#define     ACT_CIRCLES_CL       62
#define     ACT_CIRCLES_3P       63
#define   ACT_CIRCLES_LAST     63

#define   ACT_TEXTS_FIRST      71
#define     ACT_TEXTS_NORMAL     71
#define   ACT_TEXTS_LAST       71

#define   ACT_DIMS_FIRST       81
#define     ACT_DIMS_PARA        81
#define     ACT_DIMS_HOR         82
#define     ACT_DIMS_VER         83
#define     ACT_DIMS_ANGLE       84
#define     ACT_DIMS_DIAM        85
#define     ACT_DIMS_RAD         86
#define     ACT_DIMS_ARROW       87
#define   ACT_DIMS_LAST        87

#define   ACT_HATCH_FIRST      91
#define     ACT_HATCH            91
#define   ACT_HATCH_LAST       91

#define ACT_DRAW_LAST        91


// Tag:
//
#define ACT_TAG_FIRST        101
#define   ACT_TAG_ELEMENT     101
#define   ACT_TAG_CONTOUR     102
#define   ACT_UNTAG_RANGE     103
#define   ACT_TAG_RANGE       104
#define   ACT_UNTAG_INTERS    105
#define   ACT_TAG_INTERS      106
#define   ACT_TAG_LAYER       107
#define ACT_TAG_LAST         107


// Edit:
//
#define ACT_EDIT_FIRST       201
#define   ACT_EDIT_MOVE       201
#define   ACT_EDIT_ROTATE     202
#define   ACT_EDIT_SCALE      203
#define   ACT_EDIT_MIRROR     204
#define   ACT_EDIT_MOVEROTATE 205
#define   ACT_EDIT_ROTATEROTATE 206
#define   ACT_EDIT_TRIM       207
#define   ACT_EDIT_TRIM2      208
#define   ACT_EDIT_TRIM3      209
#define   ACT_EDIT_CUT        210
#define ACT_EDIT_CUT2         211
#define ACT_EDIT_STRETCH      212
#define ACT_EDIT_ROUND        213
#define ACT_EDIT_BEVEL        214
#define ACT_EDIT_TEXTELEMENTS 215
#define ACT_EDIT_TEXT         216
#define ACT_EDIT_DELETE       217
#define ACT_EDIT_LAYER        218
#define ACT_EDIT_ZERO         219
#define ACT_EDIT_ATTRIB       220
#define ACT_EDIT_CLIP         221

#define   ACT_EDIT_CLIPCOPY   225
#define   ACT_EDIT_CLIPCUT    226
#define   ACT_EDIT_CLIPPASTE  227

#define   ACT_EDIT_INSERTPART 230

#define ACT_EDIT_LAST        230


// CAM:
//
#define ACT_CAM_FIRST       501
#define   ACT_CAM_AUTO        501
#define   ACT_CAM_MANUAL      502
#define ACT_CAM_LAST        502


// Measure:
//
#define ACT_MEASURE_FIRST 601
#define   ACT_MEASURE_PTPT 601
#define   ACT_MEASURE_LNPT 602
#define   ACT_MEASURE_PARALN 603
#define   ACT_MEASURE_ANGLELNLN 604
#define   ACT_MEASURE_EDITELEMENT 605
#define   ACT_MEASURE_AREA 606
#define ACT_MEASURE_LAST 606

#endif

// EOF
